#
# spec file for package libqt5-qtlocation
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define qt5_snapshot 0

%define libname libQt5Positioning5

Name:           libqt5-qtlocation
Version:        5.12.7
Release:        1.53
Summary:        Qt 5 Location Library
License:        LGPL-2.1-with-Qt-Company-Qt-exception-1.1 or LGPL-3.0-only
Group:          Development/Libraries/X11
Url:            https://www.qt.io
%define base_name libqt5
%define real_version 5.12.7
%define so_version 5.12.7
%define tar_version qtlocation-everywhere-src-5.12.7
Source:         https://download.qt.io/official_releases/qt/5.12/%{real_version}/submodules/%{tar_version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  fdupes
BuildRequires:  libqt5-qtbase-private-headers-devel >= %{version}
BuildRequires:  libqt5-qtdeclarative-private-headers-devel >= %{version}
BuildRequires:  libicu-devel
BuildRequires:  xz
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libssl)
%if 0%{?suse_version} < 1330
# It does not build with the default compiler (GCC 4.8) on Leap 42.x
BuildRequires:  gcc7-c++
%endif
%if %qt5_snapshot
#to create the forwarding headers
BuildRequires:  perl
%endif
# needed for free, used to tune build parallelism
BuildRequires:  procps

%description
The Qt Location API facilitates creating mapping solutions using
the data available from some contemporary location services.

%prep
%setup -q -n qtlocation-everywhere-src-%{real_version}

%package -n %libname
Summary:        Qt 5 Positioning Library
Group:          Development/Libraries/X11

%description -n %libname
The Qt Positioning API gives developers the ability to determine a
position by using a variety of possible sources, including satellite,
WiFi, text file, and so on. That information can then be used to, for
example, determine a position on a map. In addition, satellite
information can be retrieved and area-based monitoring be performed.

%package -n libQt5Location5
Summary:        Qt 5 Location Library
Group:          Development/Libraries/X11

%description -n libQt5Location5
The Qt Location API facilitates creating mapping solutions using
the data available from some contemporary location services.
Using Qt Location, one can

 * access and present map data,
 * support touch gesture on a specific area of the map,
 * query for a specific geographical location and route,
 * add additional layers on top, such as polylines and circles,
 * and search for places and related images.
 
%package -n libQt5PositioningQuick5
Summary:        Qt5 Positioning Library for Qt Quick
Group:          System/Libraries

%description -n libQt5PositioningQuick5
This library contains glue code for using the Qt Location module in Qt Quick
applications.

%package devel
Summary:        Development files for the Qt5 Location Library
Group:          Development/Libraries/X11
Requires:       %libname = %{version}
Requires:       libQt5Location5 = %{version}
Requires:       libQt5PositioningQuick5 = %{version}

%description devel
The Qt Location API facilitates creating mapping solutions using
the data available from some contemporary location services.

This subpackage contains the header files for developing
applications that want to make use of the Qt Location libraries.

%package private-headers-devel
Summary:        Non-ABI stable experimental API for the Qt5 Location Library
Group:          Development/Libraries/C and C++
BuildArch:      noarch
Requires:       %{name}-devel = %{version}
Requires:       libqt5-qtbase-private-headers-devel >= %{version}
Requires:       libqt5-qtdeclarative-private-headers-devel

%description private-headers-devel
This package provides private headers of libqt5-qtlocation that are normally
not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package examples
Summary:        Qt5 location examples
Group:          Documentation/Other
Recommends:     %{name}-devel

%description examples
Examples for libqt5-qtlocation module.

%post -n %libname -p /sbin/ldconfig

%postun -n %libname -p /sbin/ldconfig

%post -n libQt5Location5 -p /sbin/ldconfig

%postun -n libQt5Location5 -p /sbin/ldconfig

%post -n libQt5PositioningQuick5 -p /sbin/ldconfig

%postun -n libQt5PositioningQuick5 -p /sbin/ldconfig

%build
%if %qt5_snapshot
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
%endif
%if 0%{?suse_version} < 1330
%qmake5 QMAKE_CC=gcc-7 QMAKE_CXX=g++-7 CONFIG+=c++14
%else
%qmake5
%endif

# do not eat all memory (logic from chromium specfile)
jobs="%{?jobs:%{jobs}}"
echo "Available memory:"
cat /proc/meminfo
echo "System limits:"
ulimit -a
if test -n "$jobs" -a "$jobs" -gt 1 ; then
    mem_per_process=900000
    max_mem=$(awk '/MemTotal/ { print $2 }' /proc/meminfo)
    max_jobs="$(($max_mem / $mem_per_process))"
    test "$jobs" -gt "$max_jobs" && jobs="$max_jobs" && echo "Warning: Reducing number of jobs to $max_jobs because of memory limits"
    test "$jobs" -le 0 && jobs=1 && echo "Warning: Do not use the parallel build at all becuse of memory limits"
fi

%__make -j$jobs VERBOSE=1

%install
%qmake5_install
find %{buildroot}/%{_libdir} -type f -name '*.la' -print -exec perl -pi -e 's, -L%{_builddir}/\S+,,g' {} +
find %{buildroot}/%{_libdir}/pkgconfig -type f -name '*.pc' -print -exec perl -pi -e 's, -L%{_builddir}/\S+,,g' {} +
# kill .la files
rm -f %{buildroot}%{_libqt5_libdir}/lib*.la

%fdupes %{buildroot}%{_libqt5_examplesdir}/

%files -n %libname
%defattr(-,root,root,755)
%license LICENSE.*
%{_libqt5_libdir}/libQt5Positioning.so.*
%dir %{_libqt5_plugindir}/position
%{_libqt5_plugindir}/position/libqtposition_geoclue.so
%{_libqt5_plugindir}/position/libqtposition_geoclue2.so
%{_libqt5_plugindir}/position/libqtposition_positionpoll.so

%files -n libQt5Location5
%defattr(-,root,root,755)
%license LICENSE.*
%{_libqt5_libdir}/libQt5Location.so.*
%{_libqt5_plugindir}/geoservices/
%{_libqt5_archdatadir}/qml/QtLocation/
%dir %{_libqt5_archdatadir}/qml/Qt/
%dir %{_libqt5_archdatadir}/qml/Qt/labs/
%{_libqt5_archdatadir}/qml/Qt/labs/location/

%files -n libQt5PositioningQuick5
%license LICENSE.*
%{_libqt5_libdir}/libQt5PositioningQuick.so.*
%{_libqt5_archdatadir}/qml/QtPositioning

%files private-headers-devel
%defattr(-,root,root,755)
%license LICENSE.*
%{_libqt5_includedir}/QtPositioning/%{so_version}
%{_libqt5_includedir}/QtLocation/%{so_version}
%{_libqt5_includedir}/QtPositioningQuick/%{so_version}

%files devel
%defattr(-,root,root,755)
%license LICENSE.*
%exclude %{_libqt5_includedir}/QtPositioning/%{so_version}
%exclude %{_libqt5_includedir}/QtLocation/%{so_version}
%exclude %{_libqt5_includedir}/QtPositioningQuick/%{so_version}
%{_libqt5_includedir}/QtPositioning
%{_libqt5_includedir}/QtLocation
%{_libqt5_includedir}/QtPositioningQuick
%{_libqt5_libdir}/cmake/Qt5Positioning
%{_libqt5_libdir}/cmake/Qt5Location
%{_libqt5_libdir}/cmake/Qt5PositioningQuick
%{_libqt5_libdir}/libQt5Positioning.prl
%{_libqt5_libdir}/libQt5Location.prl
%{_libqt5_libdir}/libQt5PositioningQuick.prl
%{_libqt5_libdir}/libQt5Positioning.so
%{_libqt5_libdir}/libQt5Location.so
%{_libqt5_libdir}/libQt5PositioningQuick.so
%{_libqt5_libdir}/pkgconfig/Qt5Positioning.pc
%{_libqt5_libdir}/pkgconfig/Qt5Location.pc
%{_libqt5_libdir}/pkgconfig/Qt5PositioningQuick.pc
%{_libqt5_libdir}/qt5/mkspecs/modules/qt_lib_*.pri

%files examples
%defattr(-,root,root,755)
%license LICENSE.*
%{_libqt5_examplesdir}/

%changelog
* Fri Jan 31 2020 fabian@ritter-vogt.de
- Update to 5.12.7:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.12.7/?h=v5.12.7
* Thu Nov 14 2019 fabian@ritter-vogt.de
- Update to 5.12.6:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.12.6/?h=v5.12.6
* Thu Sep 12 2019 christophe@krop.fr
- Update to 5.12.5:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.12.5/?h=5.12.5
* Fri Jun 14 2019 fabian@ritter-vogt.de
- Update to 5.12.4:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.12.4/?h=5.12.4
* Thu Apr 18 2019 fabian@ritter-vogt.de
- Update to 5.12.3:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.12.3/?h=v5.12.3
* Thu Mar 14 2019 fabian@ritter-vogt.de
- Update to 5.12.2:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.12.2/?h=5.12.2
* Wed Mar  6 2019 fabian@ritter-vogt.de
- Disable the gypsy plugin
- Mention all location plugins explicitly
- Move QtPositioning QML plugin to libQt5PositioningQuick5 package
* Fri Feb  1 2019 fabian@ritter-vogt.de
- Update to 5.12.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.12.1/?h=v5.12.1
* Thu Dec  6 2018 fabian@ritter-vogt.de
- Update to 5.12.0:
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.12.0/?h=v5.12.0
* Mon Dec  3 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc2:
  * New bugfix release
  * Only important bugfixes
- Changelog for Qt 5.12.0:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.12.0/?h=5.12.0
* Thu Nov 22 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc:
  * New bugfix release
  * No changelog available
* Thu Nov  8 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta4:
  * New bugfix release
  * No changelog available
* Fri Oct 26 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta3:
  * New bugfix release
  * No changelog available
* Wed Oct 17 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta1:
  * New bugfix release
  * No changelog available
* Tue Oct  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0-alpha:
  * New feature release
  * For more details please see:
  * http://wiki.qt.io/New_Features_in_Qt_5.12
* Fri Sep 21 2018 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.11.2/?h=v5.11.2
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.11.1/?h=v5.11.1
* Sat Jun  9 2018 fabian@ritter-vogt.de
- Mention libQt5PositioningQuick in baselibs.conf
* Tue May 22 2018 fabian@ritter-vogt.de
- Update to 5.11.0
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.11.0/?h=v5.11.0
* Tue May  8 2018 fabian@ritter-vogt.de
- Update to 5.11.0-rc
  * New bugfix release
  * No changelog available
* Mon Apr 23 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta4
  * New bugfix release
  * No changelog available
* Wed Apr 11 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta3
  * New bugfix release
  * No changelog available
* Wed Mar 28 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta2
  * New bugfix release
  * No changelog available
* Tue Mar 13 2018 christophe@krop.fr
- Fix the license tag.
* Thu Mar  1 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta1
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.11.0-beta1/?h=v5.11.0-beta1
* Tue Feb 20 2018 fabian@ritter-vogt.de
- Update to 5.11.0-alpha
  * New feature release
  * For more details please see:
  * https://wiki.qt.io/New_Features_in_Qt_5.11
* Wed Feb 14 2018 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlocation.git/plain/dist/changes-5.10.1/?h=v5.10.1
- Use %%license
* Fri Feb  2 2018 dimstar@opensuse.org
- Eliminate build dependency on procps: we only used it to run
  'free', in order to find out how much RAM we have available. We
  can get this information directly from the kernel, from
  /proc/meminfo.
* Fri Dec  8 2017 christophe@krop.fr
- Update the license tag (boo#967696)
* Thu Dec  7 2017 fabian@ritter-vogt.de
- Update to 5.10.0 final
  * New bugfix release
* Sun Dec  3 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 2
  * New bugfix release
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 1
  * New bugfix release
- Add some feature from the Chromium builds to determine the maximum
  allowed parallel processes based on the available memory.
* Sat Nov 25 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details, see:
    http://code.qt.io/cgit/qt/qtlocation.git/tree/dist/changes-5.9.3/?h=v5.9.3
* Fri Nov 17 2017 zaitor@opensuse.org
- Drop pkgconfig(geoclue) BuildRequires: geoclue is obsoleted by
  geoclue2, and it is not used during compilation of this package
  so just drop it.
* Wed Nov 15 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 4
- Contains bugfixes
* Thu Nov  2 2017 tittiatcoke@gmail.com
- Add some feature from the Chromium builds to determine the maximum
  allowed parallel processes based on the available memory.
* Thu Nov  2 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 3
- Contains bugfixes
* Mon Oct 30 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 2
- Contains bugfixes
* Mon Oct 30 2017 fcrozat@suse.com
- Add logic from chromium specfile to limit build parallelism based
  on available memory. Add BuildRequires procps for this.
* Mon Oct  9 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 1
- For more information visit:
    https://blog.qt.io/blog/2017/10/09/qt-5-10-beta-released/
* Sun Oct  8 2017 lbeltrame@kde.org
- Update to 5.9.2
  * For more details please see:
    https://blog.qt.io/blog/2017/10/06/qt-5-9-2-released/
* Mon Sep 25 2017 fabian@ritter-vogt.de
- Update to 5.10 Alpha 1
- For more information visit:
    https://blog.qt.io/blog/2017/09/13/qt-5-10-alpha-released/
* Mon Sep 11 2017 jengelh@inai.de
- Update package descriptions.
- Use find -exec "+" strategy.
* Sat Jul  1 2017 lbeltrame@kde.org
- Update to 5.9.1
  * For more details please see:
    http://blog.qt.io/blog/2017/06/30/qt-5-9-1-released/
* Wed May 31 2017 fabian@ritter-vogt.de
- Update to 5.9.0 final
* Wed May 24 2017 fabian@ritter-vogt.de
- Update to 5.9.0 RC:
  * For more details please see:
    http://lists.qt-project.org/pipermail/announce/2017-May/000115.html
    and https://wiki.qt.io/New_Features_in_Qt_5.9
* Wed Dec 14 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * For more details please see:
    https://blog.qt.io/blog/2016/12/14/qt-5-7-1-released/
    and https://www.qt.io/qt5-7/
* Sat Sep 24 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * For more details please see:
    https://www.qt.io/qt5-7/
* Wed Jun  8 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * For more details please see:
    http://blog.qt.io/blog/2016/06/08/qt-5-6-1-released/
* Fri Mar 18 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    http://blog.qt.io/blog/2016/03/16/qt-5-6-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.6
* Fri Oct 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1
  * For more details please see:
    http://blog.qt.io/blog/2015/10/15/qt-5-5-1-released/
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * For more details please see:
    http://blog.qt.io/blog/2015/07/01/qt-5-5-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.5
- Restore support for gypsy on Leap
* Wed Jun  3 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2
  * Bugfix release, for more details please see:
    http://blog.qt.io/blog/2015/06/02/qt-5-4-2-released/
* Tue Feb 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1
  * For more details please see:
    http://blog.qt.io/blog/2015/02/24/qt-5-4-1-released/
* Wed Dec 10 2014 hrvoje.senjan@gmail.com
- Update to 5.4 Final
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/12/10/qt-5-4-released/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
* Thu Nov 27 2014 hrvoje.senjan@gmail.com
- Update to 5.4 RC
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/11/27/qt-5-4-release-candidate-available/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
- New libQt5Location5 subpackage
* Mon Nov  3 2014 hrvoje.senjan@gmail.com
- Don't BuildRequire pkgconfig(gypsy) for SLE
- Downgrade external packages to suggests of the devel package, they
  are private deps
* Tue Sep 16 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2 final
  * No changes since previous snapshot
  * Use official tars
* Thu Sep  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2~git20140904 (r6e39a79):
  * Tip of the bugfix 5.3.2 branch
  * OSX: Fix QGeoPositionInfo attribute values with
    corelocation plug-in
  * Don't hang weatherinfo if position source has an error.
  * Enforce the use of test.source position plug-in
    in auto tests
  * Report error when failing to connect to Geoclue.
  * Add changelog for QtPositioning 5.3.2 release.
  * Fix fitViewportToMapItemsRefine
  * Avoid potential double deletion when handling
    OSM route replies
  * Fix QGeoRouteReplyOsm::networkReplyFinished
  * Fix issues with MapItemView.
  * Fixed symbol clash between sensor and positioning
    plug-in on iOS
  * Fix the names of the plugin factory classes for
    static plugin loading
* Wed Jun 25 2014 hrvoje.senjan@gmail.com
- Update to 5.3.1
  * Bugfix release, for more details please see:
    http://blog.qt.digia.com/blog/2014/06/25/qt-5-3-1-released/
* Mon Jun  2 2014 hrvoje.senjan@gmail.com
- Added baselibs.conf
- Make private headers noarch
* Mon May 19 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 final
  * Minor bugfixes over previous RC
* Thu May  8 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 RC
  * For more details, please see
  http://blog.qt.digia.com/blog/2014/05/08/qt-5-3-release-candidate-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.3
* Tue Mar 25 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 beta
  * New feature release, please see
  http://blog.qt.digia.com/blog/2014/03/25/qt-5-3-beta-released/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.3
* Fri Mar 21 2014 hrvoje.senjan@gmail.com
- Build, and add examples subpackage
* Wed Feb  5 2014 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/02/05/qt-5-2-1-released/
- Remove libtool archives from packages
* Wed Dec 18 2013 hrvoje.senjan@gmail.com
- Initialize libqt5-qtlocation package
